<?php
/* Smarty version 3.1.30, created on 2026-04-24 12:54:52
  from "/home/www/_rejestracja/template/partial/Shared/MenuBottomTree.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.30',
  'unifunc' => 'content_69eb4bfc269521_60783814',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    '9e3a6588814dfa052e48ec190d3527abe2aa7a0c' => 
    array (
      0 => '/home/www/_rejestracja/template/partial/Shared/MenuBottomTree.tpl',
      1 => 1427266882,
      2 => 'file',
    ),
  ),
  'includes' => 
  array (
  ),
),false)) {
function content_69eb4bfc269521_60783814 (Smarty_Internal_Template $_smarty_tpl) {
?>
<div class="boxBottomMenu left">
                <?php $_smarty_tpl->_assignInScope('countMenuArray', count($_smarty_tpl->tpl_vars['arrayTree']->value));
?> 
								<?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['arrayTree']->value, 'item', false, 'key', 'mainMenuBottom', array (
  'last' => true,
  'iteration' => true,
  'total' => true,
));
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['key']->value => $_smarty_tpl->tpl_vars['item']->value) {
$_smarty_tpl->tpl_vars['__smarty_foreach_mainMenuBottom']->value['iteration']++;
$_smarty_tpl->tpl_vars['__smarty_foreach_mainMenuBottom']->value['last'] = $_smarty_tpl->tpl_vars['__smarty_foreach_mainMenuBottom']->value['iteration'] == $_smarty_tpl->tpl_vars['__smarty_foreach_mainMenuBottom']->value['total'];
?>
								<?php $_smarty_tpl->_assignInScope('id', $_smarty_tpl->tpl_vars['item']->value->GetId());
?>
								<?php $_smarty_tpl->_assignInScope('lang', $_smarty_tpl->tpl_vars['item']->value->GetLang());
?>
								<?php $_smarty_tpl->_assignInScope('url', $_smarty_tpl->tpl_vars['item']->value->GetUrlWithType());
?>
								<?php $_smarty_tpl->_assignInScope('urlName', $_smarty_tpl->tpl_vars['item']->value->GetUrl());
?>
								<?php $_smarty_tpl->_assignInScope('name', $_smarty_tpl->tpl_vars['item']->value->GetMenuName());
?>
								<?php $_smarty_tpl->_assignInScope('subname', $_smarty_tpl->tpl_vars['item']->value->GetSubname());
?>
								<?php if (!$_smarty_tpl->tpl_vars['name']->value) {?> <?php $_smarty_tpl->_assignInScope('name', $_smarty_tpl->tpl_vars['item']->value->GetName());
}?>
								<?php if ($_smarty_tpl->tpl_vars['item']->value->GetType() == 1) {?>
								<div class="elementBottomMenu" <?php if ((isset($_smarty_tpl->tpl_vars['__smarty_foreach_mainMenuBottom']->value['last']) ? $_smarty_tpl->tpl_vars['__smarty_foreach_mainMenuBottom']->value['last'] : null)) {?>style="width:100px;"<?php }?>>
									<h4><a href="<?php echo $_smarty_tpl->tpl_vars['url']->value;?>
" ><?php echo $_smarty_tpl->tpl_vars['name']->value;?>
</a></h4>
									<?php if ($_smarty_tpl->tpl_vars['item']->value->GetHaveChildren()) {?>
										
											<?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['item']->value->arrayChildren, 'objElementSub', false, 'idElementSub', 'mainSubMenu', array (
));
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['idElementSub']->value => $_smarty_tpl->tpl_vars['objElementSub']->value) {
?>
											<?php $_smarty_tpl->_assignInScope('urlSub', $_smarty_tpl->tpl_vars['objElementSub']->value->GetUrlWithType());
?>
											<?php $_smarty_tpl->_assignInScope('idParentSub', $_smarty_tpl->tpl_vars['objElementSub']->value->GetId());
?>
											<div class="itemBotomMenu"><a  href="<?php echo $_smarty_tpl->tpl_vars['urlSub']->value;?>
" ><?php echo $_smarty_tpl->tpl_vars['objElementSub']->value->GetElementName();?>
</a></div>										
											<?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl);
?>

										
									<?php }?>
									<?php if ($_smarty_tpl->tpl_vars['name']->value == 'Demo') {?>
											
											<div class="itemBotomMenu"><a  href="<?php echo $_smarty_tpl->tpl_vars['url']->value;?>
" >Wersja podstawowa</a></div>										
											<div class="itemBotomMenu"><a  href="<?php echo $_smarty_tpl->tpl_vars['url']->value;?>
" >Wersja pełna</a></div>										
											<div class="itemBotomMenu"><a  href="<?php echo $_smarty_tpl->tpl_vars['url']->value;?>
" >Wersja mobilna</a></div>										
										
									<?php }?>
									
								</div>
                <?php }?>
								<?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl);
?>

				
		<div class="cb"></div>					
</div>
<div style="margin-top: 15px; text-align: left;">
	<div class="fb-like" data-href="https://www.facebook.com/pages/GoNet-CRM/435255036505963" data-width="40" data-layout="button_count" data-action="like" data-show-faces="false" data-share="false"></div>		
</div>
<div style="margin-top: 15px; text-align: left;">
	<?php echo '<script'; ?>
 src="https://apis.google.com/js/platform.js"><?php echo '</script'; ?>
>

<div class="g-ytsubscribe" data-channel="GoNetCRMSupport" data-layout="default" data-count="hidden"></div>	
</div>
<div style="margin-top: 15px; text-align: left;">
	<a href="<?php echo $_smarty_tpl->tpl_vars['urlStatic']->value;?>
/upload/GoNet_QS.exe" title=""><img src="<?php echo $_smarty_tpl->tpl_vars['urlStatic']->value;?>
/image/team_viewer.gif" alt="" /></a>
</div>
		<div class="cb"></div>					

			<?php }
}
